@@ -113,7 +113,7 @@ class Distribution(object):
             pts = np.linspace(minval,maxval,cdf_pts)
             pdfgrid = self(pts)
             cdfgrid = pdfgrid.cumsum()/pdfgrid.cumsum().max()
-            cdf_fn = interpolate(pts,cdfgrid,s=0)
+            cdf_fn = interpolate(pts,cdfgrid,s=0,k=1)
             
             def cdf(x):
                 x = np.atleast_1d(x)
@@ -122,6 +122,9 @@ class Distribution(object):
                 y[np.where(x > self.maxval)] = 1
                 return y
             self.cdf = cdf
+            #define minval_cdf, maxval_cdf 
+            self.minval_cdf = pts[cdfgrid==0][-1] #last 0 value
+            self.maxval_cdf = pts[cdfgrid==1][0] #first 1 value
 
     def pctile(self,pct,res=1000):
         """Returns the desired percentile of the distribution.
@@ -318,9 +321,16 @@ class Distribution(object):
 
         """
         if minval is None:
-            minval = self.minval
+            if hasattr(self,'minval_cdf'):
+                minval = self.minval_cdf
+            else:
+                minval = self.minval
         if maxval is None:
-            maxval = self.maxval
+            if hasattr(self,'maxval_cdf'):
+                maxval = self.maxval_cdf
+            else:
+                maxval = self.maxval
+
         if maxval==np.inf or minval==-np.inf:
             raise ValueError('must have finite upper and lower bounds to resample. (set minval, maxval kws)')
 
@@ -362,8 +372,6 @@ class Distribution_FromH5(Distribution):
         Keyword arguments are passed to the `Distribution` constructor.
     """
     def __init__(self,filename,path='',**kwargs):
-        """if disttype is 'hist' or 'kde' then samples are required
-        """
         fns = pd.read_hdf(filename,path+'/fns')
         store = pd.HDFStore(filename)
         if '{}/samples'.format(path) in store:
@@ -371,14 +379,24 @@ class Distribution_FromH5(Distribution):
             self.samples = np.array(samples)
         minval = fns['vals'].iloc[0]
         maxval = fns['vals'].iloc[-1]
-        pdf = interpolate(fns['vals'],fns['pdf'],s=0)
-        cdf = interpolate(fns['vals'],fns['cdf'],s=0)
+        pdf = interpolate(fns['vals'],fns['pdf'],s=0,k=1)
+        
+        #check to see if tabulated CDF is monotonically increasing
+        d_cdf = fns['cdf'][1:] - fns['cdf'][:-1]
+        if np.any(d_cdf <= 0):
+            logging.warning('tabulated CDF in {} is not monotonically increasing. Recalculating CDF from PDF'.format(filename))
+            cdf = None  #in this case, just recalc cdf from pdf
+        else:
+            cdf = interpolate(fns['vals'],fns['cdf'],s=0,k=1)
         Distribution.__init__(self,pdf,cdf,minval=minval,maxval=maxval,
                               **kwargs)
-        keywords = store.get_storer('{}/fns'.format(path)).attrs.keywords
+        try:
+            keywords = store.get_storer('{}/fns'.format(path)).attrs.keywords
+            for kw,val in keywords.iteritems():
+                setattr(self,kw,val)
+        except AttributeError:
+            logging.warning('saved distribution {} does not have keywords or disttype saved; perhaps this distribution was written with an older version.'.format(filename))
         store.close()
-        for kw,val in keywords.iteritems():
-            setattr(self,kw,val)
 
 
 class Empirical_Distribution(Distribution):
